@@ -21,21 +21,34 @@
 
 #include "defs.h"
 void
-fatal(const char *fmt, ...)
+fatal(const char* fmt, ...)
 {
-	va_list ap;
-	va_start(ap, fmt);
-	vfprintf(stderr, fmt, ap);
-	va_end(ap);
-	exit(1);
+  va_list ap;
+  va_start(ap, fmt);
+  vfprintf(stderr, fmt, ap);
+  va_end(ap);
+  exit(1);
 }
 
 void
-warning(const char *fmt, ...)
+warning(const char* fmt, ...)
 {
-	va_list ap;
-	va_start(ap, fmt);
-	vfprintf(stderr, fmt, ap);
-	va_end(ap);
+  va_list ap;
+  va_start(ap, fmt);
+  vfprintf(stderr, fmt, ap);
+  va_end(ap);
+}
+
+void
+debug_print(int level, const char* fmt, ...)
+{
+  va_list ap;
+  int i;
+  for (i=1; i<level; i++) {
+    fprintf(stderr, ".");
+  }
+  va_start(ap, fmt);
+  vfprintf(stderr, fmt, ap);
+  va_end(ap);
 }
 
