@@ -155,7 +155,7 @@ grössere Zahl bedeutet detailliertere Diagnosebeschreibungen.</translation>
     <message>
         <location filename="donate.ui" line="32"/>
         <source>Support GPSBabel</source>
-        <translation type="unfinished"></translation>
+        <translation>GPSBabel unterstützen</translation>
     </message>
     <message>
         <location filename="donate.ui" line="47"/>
@@ -164,27 +164,31 @@ grössere Zahl bedeutet detailliertere Diagnosebeschreibungen.</translation>
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel is free software built and supported by volunteers. It consumes vast amounts of time to create and support the software as well as money for mapping programs, GPS receivers, and development fixtures. Please see how you can &lt;a href=&quot;http://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;contribute time or via PayPal (no account needed) or Google Checkout.&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel ist freie Software, programmiert und supportet von Freiwilligen. Jede Menge Zeit ist nötig um die Software herzustellen und zu warten, und spezielle Programme, GPS Receiver etc. kosten auch Geld. Bitte &lt;a href=&quot;http://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;tragen Sie zu dem Projekt bei: Ihre Zeit oder eine Spende über PayPal (Kein Account benötigt) oder Google Checkout.&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="donate.ui" line="61"/>
         <source>&lt;p&gt;Of course, if you&apos;ve already contributed  to the project or you just can&apos;t help the project, please check the box below to never see this message again.&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;p&gt;Wenn Sie schon zu dem Projekt beigetragen haben oder Sie nicht helfen können, markieren Sie bitte die Checkbox unten um diese Meldung nicht wieder zu sehen.&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="donate.ui" line="71"/>
         <source>Never show this message again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Diese Meldung nicht mehr anzeigen</translation>
     </message>
     <message>
         <location filename="donate.ui" line="93"/>
         <source>No, Thanks</source>
-        <translation type="unfinished"></translation>
+        <translation>Nein, danke</translation>
     </message>
     <message>
         <location filename="donate.ui" line="100"/>
         <source>Contribute</source>
-        <translation type="unfinished"></translation>
+        <translation>Beitragen</translation>
     </message>
 </context>
 <context>
@@ -226,8 +230,8 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="filterdlg.cpp" line="104"/>
         <source>Are you sure you want to reset all filter options to default values?</source>
-        <translatorcomment>alt: dass = daß   - at least swiss german differs</translatorcomment>
-        <translation>Sind Sie sicher, dass Sie alle Filteroptionen auf die Vorgaben setzen wollen?</translation>
+        <translatorcomment>reset: zurücksetzen, set: setzen</translatorcomment>
+        <translation>Sind Sie sicher, dass Sie alle Filteroptionen auf die Vorgaben zurücksetzen wollen?</translation>
     </message>
 </context>
 <context>
@@ -404,12 +408,12 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="gmapui.ui" line="47"/>
         <source>Copy to Clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>In die Zwischenablage kopieren</translation>
     </message>
     <message>
         <location filename="gmapui.ui" line="50"/>
         <source>Copy</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopieren</translation>
     </message>
 </context>
 <context>
@@ -454,23 +458,23 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.cpp" line="263"/>
-        <location filename="mainwindow.cpp" line="264"/>
+        <location filename="mainwindow.cpp" line="386"/>
+        <location filename="mainwindow.cpp" line="387"/>
         <source>default</source>
         <translation>default</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="426"/>
+        <location filename="mainwindow.cpp" line="560"/>
         <source>Select one or more input files</source>
         <translation>eine oder mehrere Originaldateien markieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="453"/>
+        <location filename="mainwindow.cpp" line="587"/>
         <source>Output File Name</source>
         <translation>Zieldatei-Name</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="513"/>
+        <location filename="mainwindow.cpp" line="647"/>
         <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH
 
 This program cannot continue.</source>
@@ -479,7 +483,7 @@ This program cannot continue.</source>
 Das Programm muss abgebrochen werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="524"/>
+        <location filename="mainwindow.cpp" line="658"/>
         <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH
 
 This program cannot continue.</source>
@@ -488,121 +492,125 @@ This program cannot continue.</source>
 Das Prgramm muss abgebrochen werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="546"/>
+        <location filename="mainwindow.cpp" line="680"/>
         <source>Input and output formats do not support %1</source>
         <translation>Keine Unterstützung für %1 im Ein- oder Ausgabeformat</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="549"/>
+        <location filename="mainwindow.cpp" line="683"/>
         <source>Input does not support %1; output format supports %2</source>
         <translation>Keine Unterstützung für %1 im Eingabeformat; Ausgabeformat unterstützt %2</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="552"/>
+        <location filename="mainwindow.cpp" line="686"/>
         <source>Input format supports %1; output format does not support %2</source>
         <translation>Eingabeformat  unterstützt %1. Keine Unterstützung für %2 im Ausgabeformat</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="555"/>
+        <location filename="mainwindow.cpp" line="689"/>
         <source>Both input and output formats support %1</source>
         <translation>Ein- und Ausgabeformat unterstützen %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="576"/>
+        <location filename="mainwindow.cpp" line="710"/>
         <source>waypoints</source>
         <translation>Wegpunkte</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="577"/>
+        <location filename="mainwindow.cpp" line="711"/>
         <source>tracks</source>
         <translation>tracks</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="578"/>
+        <location filename="mainwindow.cpp" line="712"/>
         <source>routes</source>
         <translation>Routen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="668"/>
+        <location filename="mainwindow.cpp" line="802"/>
         <source>There are no input options for format &quot;%1&quot;</source>
         <translation>Es gibt keine Eingabeoptionen für das Format &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="675"/>
-        <location filename="mainwindow.cpp" line="695"/>
+        <location filename="mainwindow.cpp" line="809"/>
+        <location filename="mainwindow.cpp" line="829"/>
         <source>Options for %1</source>
         <translation>Optionen für %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="688"/>
+        <location filename="mainwindow.cpp" line="822"/>
         <source>There are no output options for format &quot;%1&quot;</source>
         <translation>Es gibt keine Ausgabeoptionen für das Format &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="709"/>
+        <location filename="mainwindow.cpp" line="843"/>
         <source>No valid waypoints/routes/tracks translation specified</source>
         <translation>keine gültige Angabe von Wegpunkt-/Routen-/Trackfiltern</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="728"/>
+        <location filename="mainwindow.cpp" line="862"/>
         <source>No input file specified</source>
         <translation>keine Quelldatei angegeben</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="735"/>
+        <location filename="mainwindow.cpp" line="869"/>
         <source>No valid output specified</source>
         <translation>keine gültiges Ziel angegeben</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="740"/>
+        <location filename="mainwindow.cpp" line="874"/>
         <source>No output file specified</source>
         <translation>keine Zieldatei angegeben</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="756"/>
+        <location filename="mainwindow.cpp" line="890"/>
         <source>Process &quot;%1&quot; did not start</source>
         <translation>Prozess &quot;%1&quot; wurde nicht gestartet</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="770"/>
+        <location filename="mainwindow.cpp" line="904"/>
         <source>Process exited unsucessfully with code %1</source>
         <translation>Prozess endete mit code %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="913"/>
+        <location filename="mainwindow.cpp" line="1047"/>
         <source>Translation successful</source>
         <translation>Konvertierung erfolgreich</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="923"/>
+        <location filename="mainwindow.cpp" line="1057"/>
         <source>Error running gpsbabel: %1
 </source>
         <translation>Fehler beim Aufruf von gpsbabel: %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1036"/>
+        <location filename="mainwindow.cpp" line="1170"/>
         <source>Are you sure you want to reset all format options to default values?</source>
         <translation>Sind Sie sicher, dass Sie alle Formatoptionen auf die Vorgaben stellen wollen?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1060"/>
+        <location filename="mainwindow.cpp" line="1194"/>
         <source>About %1</source>
         <translation>Über %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1103"/>
+        <location filename="mainwindow.cpp" line="1237"/>
         <source>One or more data filters are active</source>
         <translation>Einer oder mehrere Datenfilter sind aktiviert</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1105"/>
+        <location filename="mainwindow.cpp" line="1239"/>
         <source>No data filters are active</source>
         <translation>Keine Datenfilter sind aktiv</translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="14"/>
         <source>MainWindow</source>
-        <translation>Hauptfenster</translation>
+        <translation type="obsolete">Hauptfenster</translation>
+    </message>
+    <message>
+        <location filename="mainwinui.ui" line="14"/>
+        <source>GPSBabel</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="mainwinui.ui" line="21"/>
@@ -779,6 +787,7 @@ Das Prgramm muss abgebrochen werden.</translation>
     <message>
         <location filename="mainwinui.ui" line="508"/>
         <source>Browse for an output file name. </source>
+        <translatorcomment>no sentence</translatorcomment>
         <translation>Suchen nach Zieldatei-Namen</translation>
     </message>
     <message>
@@ -794,6 +803,7 @@ Das Prgramm muss abgebrochen werden.</translation>
     <message>
         <location filename="mainwinui.ui" line="581"/>
         <source>Options for the selected output format. </source>
+        <translatorcomment>no sentence</translatorcomment>
         <translation>Optionen für das gewählte Ausgabeformat</translation>
     </message>
     <message>
@@ -831,8 +841,7 @@ Das Prgramm muss abgebrochen werden.</translation>
     <message>
         <location filename="mainwinui.ui" line="675"/>
         <source>Check for Upgrade</source>
-        <translatorcomment>via Google Translate</translatorcomment>
-        <translation>Prüfen Sie für ein Upgrade</translation>
+        <translation>Nach Upgrade suchen</translation>
     </message>
     <message>
         <location filename="mainwinui.ui" line="680"/>
@@ -842,7 +851,7 @@ Das Prgramm muss abgebrochen werden.</translation>
     <message>
         <location filename="mainwinui.ui" line="685"/>
         <source>Make a Donation...</source>
-        <translation>Machen Sie eine Spende...</translation>
+        <translation>Spenden Sie...</translation>
     </message>
 </context>
 <context>
@@ -901,7 +910,7 @@ Das Prgramm muss abgebrochen werden.</translation>
     <message>
         <location filename="miscfltui.ui" line="34"/>
         <source>Nuke (Remove) Data Types</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestimmte Datentypen löschen</translation>
     </message>
     <message>
         <location filename="miscfltui.ui" line="72"/>
@@ -970,43 +979,42 @@ Manche Dateiformate unterstuetzen nur eine Teilmenge, entweder Wegpunkte oder Tr
     <message>
         <location filename="preferences.ui" line="20"/>
         <source>GPSBabel Preferences</source>
-        <translation type="unfinished"></translation>
+        <translation>GPSBabel Einstellungen</translation>
     </message>
     <message>
         <location filename="preferences.ui" line="30"/>
         <source>General</source>
-        <translation type="unfinished"></translation>
+        <translation>Allgemein</translation>
     </message>
     <message>
         <location filename="preferences.ui" line="45"/>
         <source>Check for newer version on start.</source>
-        <translatorcomment>Via GT</translatorcomment>
-        <translation type="unfinished">Check für neuere Version auf Start.</translation>
+        <translation>Beim Start auf neue Version überprüfen.</translation>
     </message>
     <message>
         <location filename="preferences.ui" line="52"/>
         <source>Anonymously report usage data.</source>
-        <translation type="unfinished"></translation>
+        <translation>Daten über die Benutzung anonym übertragen.</translation>
     </message>
     <message>
         <location filename="preferences.ui" line="59"/>
         <source>Ignore mismatch between command line and GUI version.</source>
-        <translation type="unfinished"></translation>
+        <translation>Konflikt zwischen Kommandozeilen- und GUI-Verson ignorieren.</translation>
     </message>
     <message>
         <location filename="preferences.ui" line="68"/>
         <source>Formats</source>
-        <translation type="unfinished"></translation>
+        <translation>Formate</translation>
     </message>
     <message>
         <location filename="preferences.ui" line="76"/>
         <source>Enabled Formats</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktivierte Formate</translation>
     </message>
     <message>
         <location filename="preferences.ui" line="100"/>
         <source>Enable All</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle aktivieren</translation>
     </message>
     <message>
         <location filename="preferences.ui" line="107"/>
@@ -1314,7 +1322,7 @@ Diese Option wird zusammen mit ihrem Gegenstück verwendet, um alle Trackpunkte
         <location filename="trackui.ui" line="203"/>
         <source>Pack all tracks into one. </source>
         <translatorcomment>no sentence</translatorcomment>
-        <translation>Alle Tracks in einem zusammenfassen.</translation>
+        <translation>Tracks zu einem Track verketten</translation>
     </message>
     <message>
         <location filename="trackui.ui" line="206"/>
@@ -1323,9 +1331,9 @@ Diese Option wird zusammen mit ihrem Gegenstück verwendet, um alle Trackpunkte
 This option causes all tracks to be appended to one another to form a single track. This option does not work if any two tracks overlap in time; in that case, consider using the merge option.
 
 This option is most useful for rejoining tracks that might have been interrupted by an equipment malfunction or an overnight stop. </source>
-        <translation>Alle Tracks in einem zusammenfassen.
+        <translation>Alle Tracks zu einem verketten.
 
-Diese Option sorgt dafür, daβ alle Tracks hintereinander zu einen gemeinsamen Track werden. Das funktioniert nicht, wenn die Zeitpunkte von Tracks überlappen. Falls das der Fall ist, kommt eher die &apos;Migrieren&apos;-Funktion in Frage.
+Diese Option sorgt dafür, daβ alle Tracks hintereinander zu einen gemeinsamen Track werden. Das funktioniert nicht, wenn die Zeitpunkte von Tracks überlappen. Falls das der Fall ist, kommt eher die &apos;Mischen&apos;-Funktion in Frage.
 
 Diese Option eignet sich am besten dafuer, Tracks zu verbinden, die durch eine Fehlfunktion oder eine automatische &apos;über-Nacht-Auftrennung&apos; aufgeteilt wurden.</translation>
     </message>
@@ -1338,27 +1346,27 @@ Diese Option eignet sich am besten dafuer, Tracks zu verbinden, die durch eine F
     <message>
         <location filename="trackui.ui" line="220"/>
         <source>Merge multiple tracks for the same way.</source>
-        <translation>Mehrere Tracks auf einem Weg zusammenfassen.</translation>
+        <translation>Tracks auf einem Weg mischen.</translation>
     </message>
     <message>
         <location filename="trackui.ui" line="223"/>
         <source> Merge multiple tracks for the same way.
 
 This option puts all track points from all tracks into a single track and sorts them by time stamp. Points with identical time stamps will be dropped. </source>
-        <translation>Mehrere Tracks auf einem Weg zusammenfassen.
+        <translation>Tracks auf einem Weg mischen.
 
 Diese Option übernimmt alle Punkte aus allen Tracks in einen einzigen Track und sortiert sie nach der Zeit. Punkte mit den gleichen Zeitdaten werden entfernt.</translation>
     </message>
     <message>
         <location filename="trackui.ui" line="228"/>
         <source>Merge</source>
-        <translation>Migrieren</translation>
+        <translation>Mischen</translation>
     </message>
     <message>
         <location filename="trackui.ui" line="235"/>
         <source>Split by Date</source>
         <oldsource>Split tracks. </oldsource>
-        <translation type="unfinished">Tracks aufspalten</translation>
+        <translation>nach Datum teilen</translation>
     </message>
     <message>
         <source>Split by date or time interval 
@@ -1392,7 +1400,7 @@ Mehrere Tracks, die sich ueber Tagesgrenzen verteilen, können so ebenfalls an D
     <message>
         <location filename="trackui.ui" line="285"/>
         <source>Split by Dist.</source>
-        <translation type="unfinished"></translation>
+        <translation>nach Entf. teilen</translation>
     </message>
     <message>
         <location filename="trackui.ui" line="297"/>
@@ -1495,7 +1503,7 @@ Diese Option erzeugt oder errechnet einen Wert für den GPS-Kurs an jeden Trackp
     <message>
         <location filename="trackui.ui" line="242"/>
         <source>Split by Time</source>
-        <translation type="unfinished"></translation>
+        <translation>nach Zeit teilen</translation>
     </message>
     <message>
         <location filename="trackui.ui" line="395"/>
@@ -1524,32 +1532,32 @@ Diese Option generiert für jeden Trackpunkt einen Geschwindigkeitswert. Sie wir
 <context>
     <name>UpgradeCheck</name>
     <message>
-        <location filename="upgrade.cpp" line="207"/>
+        <location filename="upgrade.cpp" line="216"/>
         <source>HTTP</source>
         <translation>HTTP</translation>
     </message>
     <message>
-        <location filename="upgrade.cpp" line="208"/>
+        <location filename="upgrade.cpp" line="217"/>
         <source>Download failed: %1.</source>
         <translation>Download fehlgeschlagen: %1.</translation>
     </message>
     <message>
-        <location filename="upgrade.cpp" line="237"/>
+        <location filename="upgrade.cpp" line="246"/>
         <source>Error</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="upgrade.cpp" line="238"/>
+        <location filename="upgrade.cpp" line="247"/>
         <source>Invalid return data at line %1: %2.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="upgrade.cpp" line="277"/>
+        <location filename="upgrade.cpp" line="286"/>
         <source>A new version of GPSBabel is available.&lt;br /&gt;Your version is %1 &lt;br /&gt;The latest version is %2</source>
         <translation>Eine neue Version von GPSBabel ist verfügbar.&lt;br /&gt;Die installierte Version ist %1 &lt;br /&gt;Die neueste Version ist %2</translation>
     </message>
     <message>
-        <location filename="upgrade.cpp" line="294"/>
+        <location filename="upgrade.cpp" line="303"/>
         <source>Do you wish to download an upgrade?</source>
         <translation>Möchten Sie die Aktualisierung herunter laden?</translation>
     </message>
@@ -1558,7 +1566,7 @@ Diese Option generiert für jeden Trackpunkt einen Geschwindigkeitswert. Sie wir
         <translation type="obsolete">&lt;center&gt;&lt;b&gt;Eine neue GPSBabel-Version ist verf&amp;uumlgbar&lt;/b&gt;&lt;br&gt;Die Version auf diesem Computer ist %1 &lt;br&gt;Die neueste Version ist %2&lt;/center&gt;</translation>
     </message>
     <message>
-        <location filename="upgrade.cpp" line="288"/>
+        <location filename="upgrade.cpp" line="297"/>
         <source>Upgrade</source>
         <translation>Update</translation>
     </message>
@@ -1568,27 +1576,27 @@ Diese Option generiert für jeden Trackpunkt einen Geschwindigkeitswert. Sie wir
     <message>
         <location filename="version_mismatch.ui" line="32"/>
         <source>GPSBabel Version Mismatch</source>
-        <translation type="unfinished"></translation>
+        <translation>GPSBabel Versionskonflikt</translation>
     </message>
     <message>
         <location filename="version_mismatch.ui" line="38"/>
         <source>&lt;b&gt;A version mismatch has been detected.&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Ein Versionskonflikt wurde gefunden.&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="version_mismatch.ui" line="47"/>
         <source>GPSBabel command line version:</source>
-        <translation type="unfinished"></translation>
+        <translation>GPSBabel Kommandozeilenversion:</translation>
     </message>
     <message>
         <location filename="version_mismatch.ui" line="81"/>
         <source>GPSBabel GUI version:</source>
-        <translation type="unfinished"></translation>
+        <translation>GPSBabel GUI Version:</translation>
     </message>
     <message>
         <location filename="version_mismatch.ui" line="115"/>
         <source>Never show this message again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Diese Meldung nicht mehr anzeigen</translation>
     </message>
 </context>
 <context>
@@ -1622,7 +1630,7 @@ Diese Option generiert für jeden Trackpunkt einen Geschwindigkeitswert. Sie wir
         <location filename="wayptsui.ui" line="55"/>
         <source>Suppress duplicate waypoints based on name.</source>
         <translatorcomment>no sentence</translatorcomment>
-        <translation type="unfinished">Unterdrücken gleichnamiger Wegpunkte</translation>
+        <translation>Unterdrücken gleichnamiger Wegpunkte</translation>
     </message>
     <message>
         <location filename="wayptsui.ui" line="58"/>
@@ -1764,7 +1772,7 @@ Voreinstellung ist, dass die übrig gebliebenen Punkte nach ihrer Entfernung vom
         <location filename="wayptsui.ui" line="215"/>
         <location filename="wayptsui.ui" line="218"/>
         <source>This filter sorts waypoints into alphabetical order</source>
-        <translation>Dieser Filter sortiert Wegpunkte nach Alphabet</translation>
+        <translation>Dieser Filter sortiert Wegpunkte alphabetisch</translation>
     </message>
     <message>
         <location filename="wayptsui.ui" line="221"/>
