@@ -25,46 +25,68 @@
 
 #define MYNAME "Route reversal filter"
 
+static int prev_new_trkseg;
+
 static
 arglist_t reverse_route_args[] = {
-	ARG_TERMINATOR
+  ARG_TERMINATOR
 };
 
-void 
-reverse_route_head( const route_head *rte ) 
+/*
+ * reverse_route_wpt fixes up the waypoint flag new_trkseg
+ */
+static void reverse_route_wpt(const waypoint* waypointp)
 {
-	route_reverse(rte);
-}
 
-void 
-reverse_route_process( void ) 
-{
-	route_disp_all( reverse_route_head, NULL, NULL );
+    /* Cast away const-ness */
+    waypoint* wpp = (waypoint *) waypointp;
+    
+    int curr_new_trkseg;
+    
+    curr_new_trkseg = waypointp->wpt_flags.new_trkseg;
+    wpp->wpt_flags.new_trkseg = prev_new_trkseg;
+    prev_new_trkseg = curr_new_trkseg;
 }
 
 void
-reverse_route_init(const char *args) 
+reverse_route_head(const route_head *rte)
 {
-	switch (global_opts.objective) {
-		case rtedata: break;
-		case trkdata: break;
-		default:
-			fatal(MYNAME ": This filter only works in track "
-					"or route (-t or -r) mode.\n");
-	}
+  route_reverse(rte);
+  prev_new_trkseg = 1;
 }
 
 void
-reverse_route_deinit(void) 
+reverse_route_process(void)
 {
-	/* do nothing */
+  track_disp_all(reverse_route_head, NULL, reverse_route_wpt);
+  route_disp_all(reverse_route_head, NULL, NULL);
+}
+
+void
+reverse_route_init(const char *args)
+{
+  switch (global_opts.objective) {
+  case rtedata:
+    break;
+  case trkdata:
+    break;
+  default:
+    fatal(MYNAME ": This filter only works in track "
+          "or route (-t or -r) mode.\n");
+  }
+}
+
+void
+reverse_route_deinit(void)
+{
+  /* do nothing */
 }
 
 filter_vecs_t reverse_route_vecs = {
-	reverse_route_init,
-	reverse_route_process,
-	reverse_route_deinit,
-	NULL,
-	reverse_route_args
+  reverse_route_init,
+  reverse_route_process,
+  reverse_route_deinit,
+  NULL,
+  reverse_route_args
 };
 #endif
